@@ -2,12 +2,13 @@
 
 from __future__ import annotations
 
-from model.SRGAN import SRGAN_model
-
+from .model.SRGAN import SRGAN_model
+from .train import train
 from ._factory import load_from_config, load_inference_model
 
 __all__ = [
     "SRGAN_model",
+    "train",
     "load_from_config",
     "load_inference_model",
 ]
